-- cc-auto.lua v1.1 -- "fixed" for new font by Justin, original by Tallow, 
-- based on Tak's cc program
--
-- Automatically runs many charcoal hearths or ovens simultaneously.
--

dofile("cc_Assist.lua");

askText = singleLine([[
  CC Auto v1.0 (by Tallow, based on Tak's cc program) --
  Automatically runs many charcoal hearths or ovens 
  simultaneously. Make sure the VT window is in the TOP-RIGHT corner 
  of the screen. 
]]);

BEGIN = 1;
WOOD = 2;
WATER = 3;
CLOSE = 4;
OPEN = 5;
FULL = 6;

function ccMenu()
  local passCount = promptNumber("How many passes?", 1, 1.0);
  askForFocus();
  for i=1,passCount do
    runCommand(buttons[1]);
    lsSleep(1000);
    ccRun(i, passCount);
  end
  lsPlaySound("Complete.wav");
end

function findOvens()
  local result = findAllImages("ThisIs.png");
  for i=1,#result do
    local corner = findImageInWindow("mm-corner.png",
				     result[i][0], result[i][1]);
    if not corner then
      error("Failed to find corner of cc window.");
    end
    result[i][1] = corner[1];-- - 102;
  end
  return result;
end

function setupVents(ovens)
  local result = {};
  for i=1,#ovens do
    result[i] = 0;
  end
  return result;
end

function findButton(pos, index)
  return findImageInWindow(buttons[index].image, pos[0], pos[1]);
end

function clickButton(pos, index)
  local buttonPos = findButton(pos, index);
  if buttonPos then
    safeClick(buttonPos[0] + buttons[index].offset[0],
	      buttonPos[1] + buttons[index].offset[1]);
  end
end

function ccRun(pass, passCount)
  local ovens = findOvens();
  local vents = setupVents(ovens);
  local done = false;
  while not done do
    sleepWithStatus(2000, "(" .. pass .. " / " .. passCount .. ")\n" ..
		    "Waiting for next tick");
    done = true;
  	srReadScreen();
    for i=1,#ovens do
      if not findButton(ovens[i], BEGIN) then
				vents[i] = processOven(ovens[i], vents[i]);
				done = false;
      end
    end
  end
end

 -- measurements here from mm-corner.png - NOT corner of CCOven Window
 -- new "bars" are from 66 to 259 in width. each bar is now approx 19-20
 -- coords apart vertically.
 -- lsPrintln lines for console to debug - not needed in working version
 
progressGreen = makePoint(73, 109);
maxDangerGreen = makePoint(209, 91);
minHeat = makePoint(204, 15);
minWood = makePoint(121, 53);
minOxy = makePoint(90, 34);
maxOxy = makePoint(124, 34);
maxDanger = makePoint(230, 91);
uberDanger = makePoint(240, 91);
minWater = makePoint(69, 72);

greenColor = 0x07FE05;
barColor = 0x0706FD;

function processOven(oven, vent)
  local newVent = vent;
  if pixelMatch(oven, progressGreen, greenColor, 8) then
    -- Progress is green
    --lsPrintln("Progress is Green");
    if pixelMatch(oven, maxDangerGreen, barColor, 8) then
      -- Danger too high
      --lsPrintln("Danger too High");
      clickButton(oven, WATER);
    elseif vent ~= 3 then
      newVent = 3;
      --lsPrintln("Setting Vent to Full")
      clickButton(oven, FULL);
    end
  else
    -- Progress is not green
    if not pixelMatch(oven, minHeat, barColor, 8) then
    --lsPrintln("Heat too Low");
      -- Heat too low
      if not pixelMatch(oven, minWood, barColor, 8) then
      --lsPrintln("Wood too Low");
	-- Wood too low
	clickButton(oven, WOOD);
      end
    end

    if not pixelMatch(oven, minOxy, barColor , 8) then
      -- Oxygen too low
      --lsPrintln("Oxygen too Low");
     -- lsPrintln("Setting Vent to Full");
      if vent ~= 3 then
	newVent = 3;
	clickButton(oven, FULL);
      end
    elseif pixelMatch(oven, maxOxy, barColor, 8) then
      -- Oxygen too high
     -- lsPrintln("Oxy too High");
      --lsPrintln("Setting Vent to Min")
      if vent ~= 1 then
	newVent = 1;
	clickButton(oven, CLOSE);
      end
    else
      -- Oxygen OK
      if vent ~= 2 then
      --lsPrintln("Oxy ok, setting Vent to medium");
	newVent = 2;
	clickButton(oven, OPEN);
      end
    end

    if pixelMatch(oven, maxDanger, barColor, 8) then
    --lsPrintln("Danger High");
      -- Danger > 85%
      if not pixelMatch(oven, minWater, barColor, 8) then
      --lsPrintln("Water low, adding Water");
	-- Water < 2.6%
	clickButton(oven, WATER);
	-- Splash more water if it > 90%
	if pixelMatch(oven, uberDanger, barColor, 800) then
	--lsPrintln("Adding more water")
	  clickButton(oven, WATER);
	end
      end
    end
  end
  return newVent;
end
